struct InMemoryFileSystem {
files: Arc<Mutex<HashMap<PathBuf, Arc<Vec<u8>>>>>,
}Fields
files: Arc<Mutex<HashMap<PathBuf, Arc<Vec<u8>>>>>Trait Implementations
Sourceimpl Clone for InMemoryFileSystem
impl Clone for InMemoryFileSystem
Sourcefn clone(&self) -> InMemoryFileSystem
fn clone(&self) -> InMemoryFileSystem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InMemoryFileSystem
impl Default for InMemoryFileSystem
Sourcefn default() -> InMemoryFileSystem
fn default() -> InMemoryFileSystem
Returns the “default value” for a type. Read more
Sourceimpl FileSystem for InMemoryFileSystem
impl FileSystem for InMemoryFileSystem
type Input = InMemoryInput
type Output = InMemoryOutput
Sourcefn open_input(
&self,
path: &Path,
_: bool,
) -> Result<(Self::Input, Option<Arc<File>>)>
fn open_input( &self, path: &Path, _: bool, ) -> Result<(Self::Input, Option<Arc<File>>)>
Opens an input and optionally requests that its pages be populated in advance.
Sourcefn canonicalize(&self, path: &Path) -> Result<PathBuf>
fn canonicalize(&self, path: &Path) -> Result<PathBuf>
Resolves symbolic links and returns the canonical absolute path.
Sourcefn remove_file(&self, path: &Path) -> Result<()>
fn remove_file(&self, path: &Path) -> Result<()>
Removes a file.
Sourcefn rename_file(&self, path: &Path, new_path: &Path) -> Result<()>
fn rename_file(&self, path: &Path, new_path: &Path) -> Result<()>
Rename an existing file to a new path.
Sourcefn create_output(
&self,
path: Arc<Path>,
options: OutputOptions,
) -> Result<Self::Output>
fn create_output( &self, path: Arc<Path>, options: OutputOptions, ) -> Result<Self::Output>
Creates the sized random-access output.
Sourcefn write_auxiliary(&self, path: &Path, bytes: &[u8]) -> Result
fn write_auxiliary(&self, path: &Path, bytes: &[u8]) -> Result
Writes a complete auxiliary output.