pub struct DwarfState {
dwarf: DwarfUnit,
file_id: FileId,
subprogram: UnitEntryId,
}Expand description
DWARF debug info state built incrementally during codegen.
Fields
dwarf: DwarfUnitfile_id: FileIdsubprogram: UnitEntryIdImplementations
Sourceimpl DwarfState
impl DwarfState
Sourcepub fn add_row(&mut self, code_offset: u64, srcloc: SourceLoc)
pub fn add_row(&mut self, code_offset: u64, srcloc: SourceLoc)
Emit a line program row for an instruction at the given code offset.
Sourcepub fn add_source_map_row(
&mut self,
code_offset: u64,
srcloc: SourceLoc,
source_map: &WasmSourceMap,
)
pub fn add_source_map_row( &mut self, code_offset: u64, srcloc: SourceLoc, source_map: &WasmSourceMap, )
Emit a line program row using original source information when available.