emit_eh_frame_section

Function emit_eh_frame_section 

pub fn emit_eh_frame_section(
    object: &mut Object<'static>,
    eh_frame_bytes: &[u8],
    relocations: &[EhRelocation],
    function_symbol: SymbolId,
    lsda_section_symbol: Option<SymbolId>,
) -> Result<(), CompileError>
Emit a serialized .eh_frame blob into its own section, resolving the recorded relocations against the function’s text symbol, the exception personality routine and the function’s LSDA section.