pub fn relocation_kind_to_flags(
kind: RelocationKind,
) -> Result<RelocationFlags, CompileError>Expand description
Map a Wasmer relocation kind onto the corresponding object-file relocation flags.
pub fn relocation_kind_to_flags(
kind: RelocationKind,
) -> Result<RelocationFlags, CompileError>Map a Wasmer relocation kind onto the corresponding object-file relocation flags.