pub(crate) struct TrapReader {
source: DebugInfoSource,
}Expand description
On-demand reader of per-function trap information from an ELF artifact.
Trap lookups only happen when a trap fires, so the ELF trap sections are parsed lazily instead of duplicating all trap tables in memory.
Fields
source: DebugInfoSourceImplementations
Sourceimpl TrapReader
impl TrapReader
pub(crate) fn new(source: DebugInfoSource) -> Self
Sourcepub(crate) fn lookup(
&self,
local_index: LocalFunctionIndex,
rel_pos: u32,
) -> Option<TrapInformation>
pub(crate) fn lookup( &self, local_index: LocalFunctionIndex, rel_pos: u32, ) -> Option<TrapInformation>
Looks up the trap information for local_index at rel_pos, the offset
relative to the start of the function.
fn lookup_in_image<'data, R: ReadRef<'data>>( image: &File<'data, R>, local_index: LocalFunctionIndex, rel_pos: u32, ) -> Option<TrapInformation>
fn parse_function_traps( traps_section: &[u8], trap_offset: usize, ) -> Option<Vec<TrapInformation>>