Enum wasmer_compiler::RelocationTarget [−][src]
pub enum RelocationTarget {
LocalFunc(LocalFunctionIndex),
LibCall(LibCall),
JumpTable(LocalFunctionIndex, JumpTable),
CustomSection(SectionIndex),
}Expand description
Destination function. Can be either user function or some special one, like memory.grow.
Variants
LocalFunc(LocalFunctionIndex)A relocation to a function defined locally in the wasm (not an imported one).
LibCall(LibCall)A compiler-generated libcall.
JumpTable(LocalFunctionIndex, JumpTable)Jump table index.
CustomSection(SectionIndex)Custom sections generated by the compiler