pub trait CompiledFunctionExt {
// Required method
fn linkage_name(&self) -> String;
// Provided method
fn traps_name(&self) -> String { ... }
}Expand description
Extended methods related to a compiled function.
Required Methods
Sourcefn linkage_name(&self) -> String
fn linkage_name(&self) -> String
Return a name of the function for linkage purpose.
Provided Methods
Sourcefn traps_name(&self) -> String
fn traps_name(&self) -> String
Symbol name holding the trap information for this function.