pub struct ObjectMetadataBuilder {
placeholder_data: Vec<u8>,
metadata_length: u64,
section_offset: u64,
num_function_pointers: u64,
num_trampolines: u64,
num_dynamic_function_trampoline_pointers: u64,
endianness: Endianness,
pointer_width: PointerWidth,
}Expand description
ObjectMetadataBuilder builds serialized module metadata include in an object. In addition, it also relies on information from ModuleInfo to build a table of function pointers, trmampolines and dynamic function trampoline pointers. ObjectMetadataBuilder takes care of setting up relocations, so a linker can automatically fill in actual addresses of all relevant functions. There is no need to piece the information together in the glue C file.
Fields
placeholder_data: Vec<u8>metadata_length: u64section_offset: u64num_function_pointers: u64num_trampolines: u64num_dynamic_function_trampoline_pointers: u64endianness: Endiannesspointer_width: PointerWidthImplementations
Sourceimpl ObjectMetadataBuilder
impl ObjectMetadataBuilder
Sourcepub fn new(
metadata: &ModuleMetadata,
triple: &Triple,
) -> Result<Self, ObjectError>
pub fn new( metadata: &ModuleMetadata, triple: &Triple, ) -> Result<Self, ObjectError>
Creates a new FunctionRelocsBuilder
Sourcepub fn set_section_offset(&mut self, offset: u64)
pub fn set_section_offset(&mut self, offset: u64)
Sets section offset used in relocations
Sourcepub fn placeholder_data(&self) -> &[u8] ⓘ
pub fn placeholder_data(&self) -> &[u8] ⓘ
Placeholder data for emit_data call
Sourcepub fn pointer_bytes(&self) -> u64
pub fn pointer_bytes(&self) -> u64
Bytes of a pointer for target architecture
Sourcepub fn setup_function_pointer(
&self,
obj: &mut Object<'_>,
index: usize,
symbol_id: SymbolId,
) -> Result<(), ObjectError>
pub fn setup_function_pointer( &self, obj: &mut Object<'_>, index: usize, symbol_id: SymbolId, ) -> Result<(), ObjectError>
Sets up relocation for a function pointer
Sourcepub fn setup_trampoline(
&self,
obj: &mut Object<'_>,
index: usize,
symbol_id: SymbolId,
) -> Result<(), ObjectError>
pub fn setup_trampoline( &self, obj: &mut Object<'_>, index: usize, symbol_id: SymbolId, ) -> Result<(), ObjectError>
Sets up relocation for a trampoline
Sourcepub fn setup_dynamic_function_trampoline_pointer(
&self,
obj: &mut Object<'_>,
index: usize,
symbol_id: SymbolId,
) -> Result<(), ObjectError>
pub fn setup_dynamic_function_trampoline_pointer( &self, obj: &mut Object<'_>, index: usize, symbol_id: SymbolId, ) -> Result<(), ObjectError>
Sets up relocation for a dynamic function trampoline pointer
fn function_pointers_start_offset(&self) -> u64
fn trampolines_start_offset(&self) -> u64
fn dynamic_function_trampoline_pointers_start_offset(&self) -> u64
fn serialize_value(&self, value: u64) -> Result<Vec<u8>, ObjectError>