pub struct BaseTunables {}Expand description
Tunable parameters for WebAssembly compilation.
This is the reference implementation of the Tunables trait,
used by default.
You can use this as a template for creating a custom Tunables implementation or use composition to wrap your Tunables around this one. The later approach is demonstrated in the tunables-limit-memory example.
Implementations
Sourceimpl BaseTunables
impl BaseTunables