Struct wasmer_compiler::CompiledFunction [−][src]
pub struct CompiledFunction {
pub body: FunctionBody,
pub relocations: Vec<Relocation>,
pub jt_offsets: JumpTableOffsets,
pub frame_info: CompiledFunctionFrameInfo,
}Expand description
The result of compiling a WebAssembly function.
This structure only have the compiled information data (function bytecode body, relocations, traps, jump tables and unwind information).
Fields
body: FunctionBodyThe function body.
relocations: Vec<Relocation>The relocations (in the body)
jt_offsets: JumpTableOffsetsThe jump tables offsets (in the body).
frame_info: CompiledFunctionFrameInfoThe frame information.