pub struct RkyvCompilation {
pub functions: Functions,
pub custom_sections: CustomSections,
pub function_call_trampolines: PrimaryMap<SignatureIndex, FunctionBody>,
pub dynamic_function_trampolines: PrimaryMap<FunctionIndex, FunctionBody>,
pub unwind_info: UnwindInfo,
pub got: GOT,
}Expand description
The result of compiling a WebAssembly module’s functions.
Fields
functions: FunctionsCompiled code for the function bodies.
custom_sections: CustomSectionsCustom sections for the module. It will hold the data, for example, for constants used in a function, global variables, rodata_64, hot/cold function partitioning, …
function_call_trampolines: PrimaryMap<SignatureIndex, FunctionBody>Trampolines to call a function defined locally in the wasm via a
provided Vec of values.
This allows us to call easily Wasm functions, such as:
ⓘ
let func = instance.exports.get_function("my_func");
func.call(&[Value::I32(1)]);dynamic_function_trampolines: PrimaryMap<FunctionIndex, FunctionBody>Trampolines to call a dynamic function defined in a host, from a Wasm module.
This allows us to create dynamic Wasm functions, such as:
ⓘ
fn my_func(values: &[Val]) -> Result<Vec<Val>, RuntimeError> {
// do something
}
let my_func_type = FunctionType::new(vec![Type::I32], vec![Type::I32]);
let imports = imports!{
"namespace" => {
"my_func" => Function::new(&store, my_func_type, my_func),
}
}Note: Dynamic function trampolines are only compiled for imported function types.
unwind_info: UnwindInfoSection ids corresponding to the unwind information.
got: GOTA reference to the GOT instance for the compilation.