pub struct ArtifactBuild { /* private fields */ }core or std only.Expand description
A compiled wasm module, ready to be instantiated.
Implementations
Sourceimpl ArtifactBuild
impl ArtifactBuild
Sourcepub const MAGIC_HEADER: &'static [u8; 16] = b"wasmer-universal"
pub const MAGIC_HEADER: &'static [u8; 16] = b"wasmer-universal"
Header signature for wasmu binary
Sourcepub fn is_deserializable(bytes: &[u8]) -> bool
pub fn is_deserializable(bytes: &[u8]) -> bool
Check if the provided bytes look like a serialized ArtifactBuild.
Sourcepub fn new(
inner_engine: &mut EngineInner,
data: &[u8],
target: &Target,
memory_styles: PrimaryMap<MemoryIndex, MemoryStyle>,
table_styles: PrimaryMap<TableIndex, TableStyle>,
progress_callback: Option<&CompilationProgressCallback>,
) -> Result<Self, CompileError>
Available on crate feature compiler only.
pub fn new( inner_engine: &mut EngineInner, data: &[u8], target: &Target, memory_styles: PrimaryMap<MemoryIndex, MemoryStyle>, table_styles: PrimaryMap<TableIndex, TableStyle>, progress_callback: Option<&CompilationProgressCallback>, ) -> Result<Self, CompileError>
compiler only.Compile a data buffer into a ArtifactBuild, which may then be instantiated.
Sourcepub fn from_serializable(serializable: SerializableModule) -> Self
pub fn from_serializable(serializable: SerializableModule) -> Self
Create a new ArtifactBuild from a SerializableModule
Sourcepub fn get_function_bodies_ref(
&self,
) -> &PrimaryMap<LocalFunctionIndex, FunctionBody>
pub fn get_function_bodies_ref( &self, ) -> &PrimaryMap<LocalFunctionIndex, FunctionBody>
Get Functions Bodies ref
Sourcepub fn get_function_call_trampolines_ref(
&self,
) -> &PrimaryMap<SignatureIndex, FunctionBody>
pub fn get_function_call_trampolines_ref( &self, ) -> &PrimaryMap<SignatureIndex, FunctionBody>
Get Functions Call Trampolines ref
Sourcepub fn get_dynamic_function_trampolines_ref(
&self,
) -> &PrimaryMap<FunctionIndex, FunctionBody>
pub fn get_dynamic_function_trampolines_ref( &self, ) -> &PrimaryMap<FunctionIndex, FunctionBody>
Get Dynamic Functions Call Trampolines ref
Sourcepub fn get_custom_sections_ref(
&self,
) -> &PrimaryMap<SectionIndex, CustomSection>
pub fn get_custom_sections_ref( &self, ) -> &PrimaryMap<SectionIndex, CustomSection>
Get Custom Sections ref
Sourcepub fn get_function_relocations(
&self,
) -> &PrimaryMap<LocalFunctionIndex, Vec<Relocation>>
pub fn get_function_relocations( &self, ) -> &PrimaryMap<LocalFunctionIndex, Vec<Relocation>>
Get Function Relocations
Sourcepub fn get_custom_section_relocations_ref(
&self,
) -> &PrimaryMap<SectionIndex, Vec<Relocation>>
pub fn get_custom_section_relocations_ref( &self, ) -> &PrimaryMap<SectionIndex, Vec<Relocation>>
Get Function Relocations ref
Sourcepub fn get_libcall_trampolines(&self) -> SectionIndex
pub fn get_libcall_trampolines(&self) -> SectionIndex
Get LibCall Trampoline Section Index
Sourcepub fn get_libcall_trampoline_len(&self) -> usize
pub fn get_libcall_trampoline_len(&self) -> usize
Get LibCall Trampoline Length
Sourcepub fn get_unwind_info(&self) -> &UnwindInfo
pub fn get_unwind_info(&self) -> &UnwindInfo
Get a reference to the UnwindInfo.
Sourcepub fn get_got_ref(&self) -> &GOT
pub fn get_got_ref(&self) -> &GOT
Get a reference to the GOT.
Sourcepub fn get_frame_info_ref(
&self,
) -> &PrimaryMap<LocalFunctionIndex, CompiledFunctionFrameInfo>
pub fn get_frame_info_ref( &self, ) -> &PrimaryMap<LocalFunctionIndex, CompiledFunctionFrameInfo>
Get Function Relocations ref
Sourcepub fn get_function_max_stack_usage(
&self,
) -> &PrimaryMap<LocalFunctionIndex, Option<usize>>
pub fn get_function_max_stack_usage( &self, ) -> &PrimaryMap<LocalFunctionIndex, Option<usize>>
The maximum stack allocation directly connected to the function itself if tracked (does not include any potential function calls). Available only for the Singlepass compiler